==> Commons-0.8.0.tgz: Commons-0.8.0/Exception.php <==
<?php
/* vim: set tabstop=4 shiftwidth=4: */

/*
 * Commons Top Level Exception
 * 
 *
 * PHP version 5
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @category   PHP
 * @package    Commons
 * @author     Yomei Komiya
 * @copyright  2007 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    SVN: $Id: Exception.php 80 2008-01-02 12:54:29Z whitestar $
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      File available since Release 0.8.0
 */

//namespace Commons;

require_once 'PEAR/Exception.php';

/**
 * Commons top level exception
 *
 *
 * @category   PHP
 * @package    Commons
 * @author     Yomei Komiya
 * @copyright  2007 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    Release: 0.8.0
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      Class available since Release 0.8.0
 */
class Commons_Exception extends PEAR_Exception {
//class Exception extends PEAR_Exception {

	/**
	 * Constructor
	 * 
	 * Supported signatures:
	 *  - Commons_Exception(string $message);
	 *  - Commons_Exception(string $message, int $code);
	 *  - Commons_Exception(string $message, Exception $cause);
	 *  - Commons_Exception(string $message, Exception $cause, int $code);
	 *  - Commons_Exception(string $message, PEAR_Error $cause);
	 *  - Commons_Exception(string $message, PEAR_Error $cause, int $code);
	 *  - Commons_Exception(string $message, array $causes);
	 *  - Commons_Exception(string $message, array $causes, int $code);
	 * @param string exception message
	 * @param int|Exception|PEAR_Error|array|null exception cause
	 * @param int|null exception code or null
	 */
	public function Commons_Exception($message, $p2 = null, $p3 = null) {
		parent::__construct($message, $p2, $p3);
	}
	
}

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * c-hanging-comment-ender-p: nil
 * End:
 */
?>

==> Commons-0.9.0.tgz: Commons-0.9.0/Exception.php <==
<?php
/* vim: set tabstop=4 shiftwidth=4: */

/*
 * Commons Top Level Exception
 * 
 *
 * PHP version 5
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @category   PHP
 * @package    Commons
 * @author     Yomei Komiya
 * @copyright  2007,2008 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    SVN: $Id: Exception.php 170 2008-01-27 03:34:40Z whitestar $
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      File available since Release 0.8.0
 */

//namespace Commons;

require_once 'PEAR/Exception.php';

/**
 * Commons top level exception
 *
 *
 * @category   PHP
 * @package    Commons
 * @author     Yomei Komiya
 * @copyright  2007,2008 the original author or authors.
 * @license    http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @version    Release: 0.9.0
 * @link       http://phpcommons.sourceforge.jp/
 * @see        
 * @since      Class available since Release 0.8.0
 */
class Commons_Exception extends PEAR_Exception {
//class Exception extends PEAR_Exception {

	/**
	 * Constructor
	 * 
	 * Supported signatures:
	 *  - Commons_Exception(string $message);
	 *  - Commons_Exception(string $message, int $code);
	 *  - Commons_Exception(string $message, Exception $cause);
	 *  - Commons_Exception(string $message, Exception $cause, int $code);
	 *  - Commons_Exception(string $message, PEAR_Error $cause);
	 *  - Commons_Exception(string $message, PEAR_Error $cause, int $code);
	 *  - Commons_Exception(string $message, array $causes);
	 *  - Commons_Exception(string $message, array $causes, int $code);
	 * @param string exception message
	 * @param int|Exception|PEAR_Error|array|null exception cause
	 * @param int|null exception code or null
	 */
	public function Commons_Exception($message, $p2 = null, $p3 = null) {
		parent::__construct($message, $p2, $p3);
	}
	
	
	/**
	 * Prints stack trace to stream.
	 *
	 * @param stream $stream stream (default: php://stderr)
	 * @since 0.9.0
	 */
	public function printStackTrace($stream = null) {
		// for each Commons_Exception and Commons_Lang_StdErr requires the other.
		if (!class_exists('Commons_Lang_StdErr', false)) {
			require 'Commons/Lang/StdErr.php';
		}
		if (!class_exists('Commons_Lang_SystemUtils', false)) {
			require 'Commons/Lang/SystemUtils.php';
		}
		
		$stackTrace = self::stackTraceString($this);
		if (is_null($stream)) {
			Commons_Lang_StdErr::println($stackTrace);
		}
		else {
			fwrite($stream, $stackTrace . Commons_Lang_SystemUtils::getLineSeparator());
		}
	}
	
	
	/**
	 * Obtains stack trace string.
	 *
	 * @param Exception $e
	 * @return string
	 * @since 0.9.0
	 */
	public static function stackTraceString(Exception $e) {
		// TODO
		return $e->__toString();
	}
	
}

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * c-hanging-comment-ender-p: nil
 * End:
 */
?>
